<div class="row mb-3">
    <label for="meta_keywords" class="form-label ol-form-label col-sm-2 col-form-label">{{ get_phrase('Keywords') }}</label>
    <div class="col-sm-10">
        <input type="text" name="meta_keywords" class="form-control tagify" id="meta_keywords">
    </div>
</div>

<div class="row mb-3">
    <label for="meta_description" class="form-label ol-form-label col-sm-2 col-form-label">{{ get_phrase('Description') }}</label>
    <div class="col-sm-10">
        <textarea class="form-control ol-form-control" name="meta_description" name="meta_description" rows="4"></textarea>
    </div>
</div>
