<div class="tab-pane fade @if ($tab == 'summary') show active @endif" id="pills-summary" role="tabpanel" aria-labelledby="pills-summary-tab" tabindex="0">
    <div class="summery-tab-content">
        <p class="info">{!! removeScripts($lesson_details->summary ?? '') !!}</p>
    </div>
</div>
