<div class="form-group">
    <label class="form-label ol-form-label">{{ get_phrase('Iframe source') }}( {{ get_phrase('Provide the source only') }})</label>
    <input value="{{$lessons->lesson_src}}" type="text" id="iframe_source" name="iframe_source" class="form-control ol-form-control"
        placeholder="{{ get_phrase('Provide the source only') }}">
</div>
