<div class="row">
    <div class="col-md-6">
        <div class="ol-card p-4 ol-card p-4-2">
            <div class="card-body">
                <div class="d-flex justify-content-center">
                    <div class="theme_box">
                        <div class="theme_image_custom">
                            <img src="{{ asset('uploads/theme_image/home_1.png') }}">
                        </div>
                    </div>
                </div>
                <div>
                    <a class="eBtn eBtn-blue w-100 mt-4" href="">
                        {{ get_phrase('Activated') }}
                        {{ get_phrase('Active') }}

                    </a>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="ol-card p-4 ol-card p-4-2">
            <div class="card-body">
                <div class="d-flex justify-content-center">
                    <div class="theme_box">
                        <div class="theme_image_custom">
                            <img src="">
                        </div>
                    </div>
                </div>
                <div>
                    <a class="eBtn eBtn-blue w-100 mt-4" href="">
                        {{ get_phrase('Activated') }}
                        {{ get_phrase('Active') }}

                    </a>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="ol-card p-4 ol-card p-4-2">
            <div class="card-body">
                <div class="d-flex justify-content-center">
                    <div class="theme_box">
                        <div class="theme_image_custom">
                            <img src="">
                        </div>
                    </div>
                </div>
                <div>
                    <a class="eBtn eBtn-blue w-100 mt-4" href="">
                        {{ get_phrase('Activated') }}
                        {{ get_phrase('Active') }}

                    </a>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="ol-card p-4 ol-card p-4-2">
            <div class="card-body">
                <div class="d-flex justify-content-center">
                    <div class="theme_box">
                        <div class="theme_image_custom">
                            <img src="">
                        </div>
                    </div>
                </div>
                <div>
                    <a class="eBtn eBtn-blue w-100 mt-4" href="">
                        {{ get_phrase('Activated') }}
                        {{ get_phrase('Active') }}

                    </a>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="ol-card p-4 ol-card p-4-2">
            <div class="card-body">
                <div class="d-flex justify-content-center">
                    <div class="theme_box">
                        <div class="theme_image_custom">
                            <img src="">
                        </div>
                    </div>
                </div>
                <div>
                    <a class="eBtn eBtn-blue w-100 mt-4" href="">
                        {{ get_phrase('Activated') }}
                        {{ get_phrase('Active') }}

                    </a>
                </div>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="ol-card p-4 ol-card p-4-2">
            <div class="card-body">
                <div class="d-flex justify-content-center">
                    <div class="theme_box">
                        <div class="theme_image_custom">
                            <img src="">
                        </div>
                    </div>
                </div>
                <div>
                    <a class="eBtn eBtn-blue w-100 mt-4" href="">
                        {{ get_phrase('Activated') }}
                        {{ get_phrase('Active') }}

                    </a>
                </div>
            </div>
        </div>
    </div>

</div>
