.article-title {
  font-weight: 300;
  font-size: 4.2rem;
  border-bottom: 1px solid #eff1f2;
  max-width: 650px;
  margin: 0 0 40px;
  word-break: break-word;
  color: #3b454e;
}

.article-body,
.editor-body {
  font-size: 1.6rem;
  font-weight: 400;
  line-height: 24px;
  color: #3b454e;
}
.article-body ul,
.article-body ol,
.editor-body ul,
.editor-body ol {
  font-size: inherit;
  font-weight: inherit;
  margin-top: 10px;
  position: relative;
}
.article-body ul > li,
.article-body ol > li,
.editor-body ul > li,
.editor-body ol > li {
  margin-bottom: 8px;
}
.article-body ul,
.editor-body ul {
  padding-left: 40px;
  position: relative;
}
.article-body ul > li,
.editor-body ul > li {
  list-style-type: disc;
  margin-bottom: 7px;
}
.article-body ol,
.editor-body ol {
  counter-reset: custom-counter;
  list-style: none;
}
.article-body ol > li:before,
.editor-body ol > li:before {
  content: counter(custom-counter, decimal) '.';
  counter-increment: custom-counter;
  font-weight: 500;
  position: absolute;
  left: -10px;
  width: 40px;
  text-align: right;
}
.article-body strong,
.editor-body strong {
  font-weight: 500;
  color: #43484d;
}
.article-body img,
.editor-body img {
  max-width: 100%;
  height: auto;
  margin: 25px auto;
  padding: 5px;
  border-radius: 3px;
  box-shadow: #f7f7ff 0px 0px 0px 2px;
}
.article-body hr,
.editor-body hr {
  background-color: #eaeaea;
  height: 2px;
  border: 0;
  width: 100%;
}
.article-body h1 > a,
.article-body h2 > a,
.article-body h3 > a,
.editor-body h1 > a,
.editor-body h2 > a,
.editor-body h3 > a {
  color: inherit;
}
.article-body h1 > a:hover,
.article-body h2 > a:hover,
.article-body h3 > a:hover,
.editor-body h1 > a:hover,
.editor-body h2 > a:hover,
.editor-body h3 > a:hover {
  text-decoration: none;
}
.article-body h2:first-child,
.editor-body h2:first-child {
  border-top: none;
  margin-top: 0;
  padding-top: 0;
  margin-bottom: 22px;
}
.article-body h1,
.editor-body h1 {
  font-size: 4.2rem;
  font-weight: 300;
  line-height: normal;
  margin: 0;
}
.article-body h2,
.editor-body h2 {
  font-size: 2.4rem;
  font-weight: 400;
  line-height: normal;
  padding-top: 30px;
  margin-top: 45px;
  border-top: 1px solid #e0e0e0;
}
.article-body h3,
.editor-body h3 {
  font-size: 2rem;
  font-weight: 400;
  margin: 35px 0 10px;
}
.article-body p,
.editor-body p {
  margin: 10px 0 25px;
  letter-spacing: 0.3px;
  overflow: hidden;
  line-height: 24px;
}
.article-body pre,
.editor-body pre {
  overflow: auto;
  max-width: 100%;
  padding: 10px;
  margin: 15px 0 20px;
  font-size: 1.5rem;
  border-radius: 5px;
  background-color: rgba(238, 238, 238, 0.35);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.125);
}
.article-body pre > code,
.editor-body pre > code {
  border-radius: 0;
  color: inherit;
  padding: 0;
}
.article-body :not(pre) > code,
.editor-body :not(pre) > code {
  font-family:
    Droid Sans Mono,
    monospace;
  background-color: #f1f1f1;
  border-radius: 4px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.125);
  font-size: 75%;
  color: #c7254e;
  padding: 2px 4px;
  letter-spacing: 0;
}
.article-body a,
.editor-body a {
  color: #1e88e5;
}
.article-body a:hover,
.editor-body a:hover {
  text-decoration: underline;
}
.article-body table,
.editor-body table {
  margin: 0;
  border-collapse: collapse;
  border-spacing: 0;
  background-color: transparent;
}
.article-body table thead > tr,
.editor-body table thead > tr {
  background-color: #fafafa;
}
.article-body table td,
.editor-body table td {
  padding: 8px;
  vertical-align: top;
  border: 1px solid #e0e0e0;
}
.article-body table th,
.editor-body table th {
  text-align: left;
  padding: 8px;
  vertical-align: bottom;
  border-bottom: 2px solid #e0e0e0;
  color: #43484d;
  font-weight: 400;
}
.article-body table tr:nth-of-type(even),
.editor-body table tr:nth-of-type(even) {
  background-color: #fafafa;
}
.article-body .widget,
.editor-body .widget {
  background-color: #f3fbf7;
  max-width: 100%;
  padding: 14px;
  margin: 35px 0;
  border-radius: 3px;
  overflow-wrap: break-word;
  border-left: 5px solid #5ac891;
  font-size: 1.7rem;
}
.article-body .widget > .title,
.editor-body .widget > .title {
  font-weight: 500;
  color: #43484d;
}
.article-body .widget.widget-important,
.editor-body .widget.widget-important {
  background-color: #fef7ed;
  border-left: 5px solid #f3a12c;
}
.article-body .widget.widget-warning,
.editor-body .widget.widget-warning {
  background-color: #f2564d;
  border-left: 5px solid #6b0d08;
}
@media only screen and (max-width: 641px) {
  .article-body,
  .editor-body {
    font-size: 1.6rem;
  }
  .article-body widget.widget-info,
  .editor-body widget.widget-info {
    font-size: inherit;
  }
}

.tsd-is-private {
  display: none;
}

.tsd-anchor {
  display: block;
  height: 0;
}

.tsd-panel-group {
  margin-bottom: 40px;
}

.tsd-panel {
  -webkit-box-shadow: 0 0 4px rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.25);
  margin-bottom: 25px;
  padding: 15px;
}

.tsd-panel ul.tsd-signatures,
.tsd-panel ul.tsd-descriptions {
  list-style: none;
  padding-left: 0;
}
.tsd-panel ul.tsd-signatures > li,
.tsd-panel ul.tsd-descriptions > li {
  list-style-type: none;
  margin: 0;
}

.tsd-panel .tsd-sources {
  display: none;
}

.tsd-panel .tsd-signature-type,
.tsd-panel .tsd-signature-symbol {
  font-weight: 400;
  font-style: italic;
  font-family:
    Droid Sans Mono,
    monospace;
}

.tsd-panel .tsd-kind-method {
  font-family:
    Droid Sans Mono,
    monospace;
  border-top: 1px solid #e6ecf1;
  border-bottom: 1px solid #e6ecf1;
  padding: 15px 0;
  margin: 0;
}

.tsd-panel .ts-flagDefault {
  display: none;
}

.tsd-panel h3 {
  margin: 0 0 18px;
  color: #1e88e5;
  line-height: 24px;
  font-weight: 500;
  font-size: 1.8rem;
}

.tsd-panel h4 {
  font-size: 1.5rem;
}

.tsd-panel h5 {
  font-size: 1.4rem;
}

.tsd-panel a {
  color: inherit;
  pointer-events: none;
}

.editor-body {
  margin: 15px 20px;
}
