<div class="form-group mb-2">
    <label class="form-label ol-form-label"> {{ get_phrase('Attachment') }}</label>
    <div class="input-group">
        <div class="custom-file w-100">
            <input type="file" class="form-control ol-form-control" id="attachment" name="attachment">
        </div>
    </div>
</div>
