{{-- To make a editable image or text need to be add a "builder editable" class and builder identity attribute with a unique value --}}
{{-- builder identity and builder editable --}}
{{-- builder identity value have to be unique under a single file --}}

<!-- <section class="performance-wrapper section-padding">
    <div class="container">
        <div class="pr-wrap">
            <div class="row">
                <div class="col-lg-3 col-md-6 col-sm-6  ps-border">
                    <div class="ps-single-wrap">
                        <img class="builder-editable" builder-identity="1" src="{{asset('assets/page-builder/block-image/p1.png')}}" alt="...">
                        <h4 class="builder-editable" builder-identity="2">Fast Performance</h4>
                        <p class="description builder-editable" builder-identity="3">It is a long established fact that a reader will be distracted.</p>
                    </div>
                </div>
                <div class="col-lg-3 col-md-6 col-sm-6 ps-border">
                    <div class="ps-single-wrap">
                        <img class="builder-editable" builder-identity="4" src="{{asset('assets/page-builder/block-image/p2.png')}}" alt="...">
                        <h4 class="builder-editable" builder-identity="5">Perfect Responsive</h4>
                        <p class="description builder-editable" builder-identity="6">It is a long established fact that a reader will be distracted.</p>
                    </div>
                </div>
                <div class="col-lg-3 col-md-6 col-sm-6 ps-border">
                    <div class="ps-single-wrap">
                        <img class="builder-editable" builder-identity="7" src="{{asset('assets/page-builder/block-image/p3.png')}}" alt="...">
                        <h4 class="builder-editable" builder-identity="8">Fast & Friendly Support</h4>
                        <p class="description builder-editable" builder-identity="9">It is a long established fact that a reader will be distracted.</p>
                    </div>
                </div>
                <div class="col-lg-3 col-md-6 col-sm-6 ps-border">
                    <div class="ps-single-wrap">
                        <img class="builder-editable" builder-identity="10" src="{{asset('assets/page-builder/block-image/p4.png')}}" alt="...">
                        <h4 class="builder-editable" builder-identity="11">Easy to Use</h4>
                        <p class="description builder-editable" builder-identity="12">It is a long established fact that a reader will be distracted.</p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section> -->
