<meta property="og:site_name" content="{{ settings('branding.site_name') }}" />
<meta property="twitter:card" content="summary" />
<title>{{ __('Help Center') }} - {{ settings('branding.site_name') }}</title>
<meta
    property="og:title"
    content="{{ __('Help Center') }} - {{ settings('branding.site_name') }}"
/>
<meta property="og:url" content="{{ urls()->home() }}" />
<link rel="canonical" href="{{ urls()->home() }}" />
<meta
    property="og:description"
    content="{{ __("Articles, Tutorials, FAQ's and more.") }}"
/>
<meta
    property="description"
    content="{{ __("Articles, Tutorials, FAQ's and more.") }}"
/>
<meta property="og:type" content="website" />
