<div class="form-group mb-2">
    <label class="form-label ol-form-label">{{ get_phrase('Iframe source') }} <small class="text-muted">({{ get_phrase('Provide the source url only') }})</small></label>
    <input type="link" id="iframe_source" name="iframe_source" class="form-control ol-form-control" placeholder="{{ get_phrase('Provide the source only') }}">
</div>
