<div class="card-centered-section">
    <div class="card-middle-banner">
        <img src="{{ get_image('assets/backend/images/img/no-file-search.svg') }}" alt="">
    </div>
    <p class="title2 fs-20px text-center">{{ get_phrase('No data found') }}</p>
</div>
