{{-- To make a editable image or text need to be add a "builder editable" class and builder identity attribute with a unique value --}}
{{-- builder identity and builder editable --}}
{{-- builder identity value have to be unique under a single file --}}

<section class="testimonials-wrapper section-padding">
    <span class="elips left-elips"><img class="builder-editable" builder-identity="1" src="{{ asset('assets/page-builder/block-image/Ellipse 8.png') }}" alt="..."></span>
    <span class="elips right-elips"><img class="builder-editable" builder-identity="2" src="{{ asset('assets/page-builder/block-image/Ellipse 9.png') }}" alt="..."></span>
    <div class="container">
        <div class="row">
            <div class="col-lg-4 col-md-4">
                <div class="section-title ">
                    <span class="title-head builder-editable" builder-identity="3">{{ get_phrase('Testimonial') }}</span>
                    <h2 class="title builder-editable" builder-identity="4">{{ get_phrase('What our clients says about us') }}</h2>
                    <p class="description mt-5 builder-editable" builder-identity="5">{{ get_phrase('It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.') }}</p>
                </div>
            </div>
            <div class="col-lg-8 col-md-8">
                <div class="user-slider owl-carousel owl-theme">
                    <!-- Single User Opinion -->
                    <div class="single-opinion">
                        <div class="user-image">
                            <img class="builder-editable" builder-identity="6" src="{{ asset('assets/page-builder/block-image/test-image.png') }}" alt="">
                        </div>
                        <div class="testimonial-border">
                            <div class="testimonial-des">
                                <p class="description">
                                    <span class="builder-editable" builder-identity="7">{{ get_phrase('It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of use Lorem Ipsum.') }}</span>
                                </p>
                                <div class="user-info d-flex">
                                    <div>
                                        <h4><span class="builder-editable" builder-identity="8">{{ get_phrase('Linchon Philips') }}</span></h4>
                                        <p><span class="builder-editable" builder-identity="9">{{ get_phrase('CEO @ Yahoo') }}</span></p>
                                    </div>
                                    <ul class="d-flex align-items-center">
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Single User Opinion -->
                    <div class="single-opinion">
                        <div class="user-image">
                            <img class="builder-editable" builder-identity="10" src="{{ asset('assets/page-builder/block-image/test-image.png') }}" alt="">
                        </div>
                        <div class="testimonial-border">
                            <div class="testimonial-des">
                                <p class="description"><span class="builder-editable" builder-identity="11">{{ get_phrase('It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of use Lorem Ipsum.') }}</span></p>
                                <div class="user-info d-flex">
                                    <div>
                                        <h4><span class="builder-editable" builder-identity="12">{{ get_phrase('Linchon Philips') }}</span></h4>
                                        <p><span class="builder-editable" builder-identity="13">{{ get_phrase('CEO @ Yahoo') }}</span></p>
                                    </div>
                                    <ul class="d-flex align-items-center">
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Single User Opinion -->
                    <div class="single-opinion">
                        <div class="user-image">
                            <img class="builder-editable" builder-identity="14" src="{{ asset('assets/page-builder/block-image/test-image.png') }}" alt="">
                        </div>
                        <div class="testimonial-border">
                            <div class="testimonial-des">
                                <span class="description"><span class="builder-editable" builder-identity="15">{{ get_phrase('It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of use Lorem Ipsum.') }}</span></p>
                                    <div class="user-info d-flex">
                                        <div>
                                            <h4><span class="builder-editable" builder-identity="16">{{ get_phrase('Linchon Philips') }}</span></h4>
                                            <p><span class="builder-editable" builder-identity="17">{{ get_phrase('CEO @ Yahoo') }}</span></p>
                                        </div>
                                        <ul class="d-flex align-items-center">
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                            <li><i class="fa fa-star"></i></li>
                                        </ul>
                                    </div>
                            </div>
                        </div>
                    </div>
                    <!-- Single User Opinion -->
                    <div class="single-opinion">
                        <div class="user-image">
                            <img class="builder-editable" builder-identity="18" src="{{ asset('assets/page-builder/block-image/test-image.png') }}" alt="">
                        </div>
                        <div class="testimonial-border">
                            <div class="testimonial-des">
                                <p class="description"><span class="builder-editable" builder-identity="19">{{ get_phrase('It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of use Lorem Ipsum.') }}</span></p>
                                <div class="user-info d-flex">
                                    <div>
                                        <h4><span class="builder-editable" builder-identity="20">{{ get_phrase('Linchon Philips') }}</span></h4>
                                        <p><span class="builder-editable" builder-identity="21">{{ get_phrase('CEO @ Yahoo') }}</span></p>
                                    </div>
                                    <ul class="d-flex align-items-center">
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Single User Opinion -->
                    <div class="single-opinion">
                        <div class="user-image">
                            <img class="builder-editable" builder-identity="22" src="{{ asset('assets/page-builder/block-image/test-image.png') }}" alt="">
                        </div>
                        <div class="testimonial-border">
                            <div class="testimonial-des">
                                <p class="description"><span class="builder-editable" builder-identity="23">{{ get_phrase('It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of use Lorem Ipsum.') }}</span></p>
                                <div class="user-info d-flex">
                                    <div>
                                        <h4><span class="builder-editable" builder-identity="24">{{ get_phrase('Linchon Philips') }}</span></h4>
                                        <p><span class="builder-editable" builder-identity="25">{{ get_phrase('CEO @ Yahoo') }}</span></p>
                                    </div>
                                    <ul class="d-flex align-items-center">
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                        <li><i class="fa fa-star"></i></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Single User Opinion -->
                </div>
            </div>
        </div>
    </div>
</section>
<script>
    $('.testimonials-wrapper .user-slider').owlCarousel({
        loop: false,
        autoplay: false,
        margin: 10,
        nav: true,
        navText: ['<i class="fa-solid fa-chevron-left"></i>', '<i class="fa-solid fa-chevron-right"></i>'],
        dots: false,
        responsive: {
            0: {
                items: 1
            },
            600: {
                items: 1
            },
            1000: {
                items: 1
            }
        }
    });
</script>
